@@ -13,3 +13,6 @@ pub use aom::RowsIter;
 
 /// Helper functions for undoing chroma subsampling
 pub mod chroma;
+
+#[cfg(feature = "avif")]
+pub mod avif;
